==> jupyterlab_urdf-0.1.2.tar.gz: jupyterlab_urdf-0.1.2/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.1.2

([Full Changelog](https://github.com/ihuicatl/jupyterlab-urdf/compare/v0.1.1...36b5a10537e1d507d69decc6e39b80b4a20b88e1))

### Bugs fixed

- Fix movement for undefined limits [#17](https://github.com/ihuicatl/jupyterlab-urdf/pull/17) ([@vkmb](https://github.com/vkmb))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ihuicatl/jupyterlab-urdf/graphs/contributors?from=2022-07-20&to=2022-07-29&type=c))

[@github-actions](https://github.com/search?q=repo%3Aihuicatl%2Fjupyterlab-urdf+involves%3Agithub-actions+updated%3A2022-07-20..2022-07-29&type=Issues) | [@ihuicatl](https://github.com/search?q=repo%3Aihuicatl%2Fjupyterlab-urdf+involves%3Aihuicatl+updated%3A2022-07-20..2022-07-29&type=Issues) | [@vkmb](https://github.com/search?q=repo%3Aihuicatl%2Fjupyterlab-urdf+involves%3Avkmb+updated%3A2022-07-20..2022-07-29&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.1.1

([Full Changelog](https://github.com/ihuicatl/jupyterlab-urdf/compare/v0.1.0a0...780dbc0d67539230876d15c3bf1fd9d4dc7e264a))

### Enhancements made

- Configure JupyterLite [#6](https://github.com/ihuicatl/jupyterlab-urdf/pull/6) ([@ihuicatl](https://github.com/ihuicatl))

### Bugs fixed

- Reload robot once error in XML file is cleared [#14](https://github.com/ihuicatl/jupyterlab-urdf/pull/14) ([@ihuicatl](https://github.com/ihuicatl))

### Documentation improvements

- Update README to include JupyterLite [#13](https://github.com/ihuicatl/jupyterlab-urdf/pull/13) ([@ihuicatl](https://github.com/ihuicatl))
- Configure JupyterLite [#6](https://github.com/ihuicatl/jupyterlab-urdf/pull/6) ([@ihuicatl](https://github.com/ihuicatl))
- Update installation instructions [#5](https://github.com/ihuicatl/jupyterlab-urdf/pull/5) ([@ihuicatl](https://github.com/ihuicatl))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ihuicatl/jupyterlab-urdf/graphs/contributors?from=2022-07-06&to=2022-07-20&type=c))

[@github-actions](https://github.com/search?q=repo%3Aihuicatl%2Fjupyterlab-urdf+involves%3Agithub-actions+updated%3A2022-07-06..2022-07-20&type=Issues) | [@ihuicatl](https://github.com/search?q=repo%3Aihuicatl%2Fjupyterlab-urdf+involves%3Aihuicatl+updated%3A2022-07-06..2022-07-20&type=Issues)

## 0.1.0a0

([Full Changelog](https://github.com/ihuicatl/jupyterlab-urdf/compare/3f5977ccd1cbfe59df27b9dc34f5e654da0d1ca9...5ce469cf2ae263c3be22c653150db22d2a5c19b5))

### Enhancements made

- Amphion [#2](https://github.com/ihuicatl/jupyterlab-urdf/pull/2) ([@hbcarlos](https://github.com/hbcarlos))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ihuicatl/jupyterlab-urdf/graphs/contributors?from=2022-06-10&to=2022-07-06&type=c))

[@hbcarlos](https://github.com/search?q=repo%3Aihuicatl%2Fjupyterlab-urdf+involves%3Ahbcarlos+updated%3A2022-06-10..2022-07-06&type=Issues)

==> jupyterlab_urdf-0.2.0.tar.gz: jupyterlab_urdf-0.2.0/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.2.0

([Full Changelog](https://github.com/ihuicatl/jupyterlab-urdf/compare/v0.1.2...1c83122721711101f1973080b98eb7a359aebb6d))

### Enhancements made

- Add jupyter-rospkg dependency [#23](https://github.com/ihuicatl/jupyterlab-urdf/pull/23) ([@ihuicatl](https://github.com/ihuicatl))

### Documentation improvements

- Update documentation [#24](https://github.com/ihuicatl/jupyterlab-urdf/pull/24) ([@ihuicatl](https://github.com/ihuicatl))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ihuicatl/jupyterlab-urdf/graphs/contributors?from=2022-07-29&to=2022-09-22&type=c))

[@github-actions](https://github.com/search?q=repo%3Aihuicatl%2Fjupyterlab-urdf+involves%3Agithub-actions+updated%3A2022-07-29..2022-09-22&type=Issues) | [@ihuicatl](https://github.com/search?q=repo%3Aihuicatl%2Fjupyterlab-urdf+involves%3Aihuicatl+updated%3A2022-07-29..2022-09-22&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.1.2

([Full Changelog](https://github.com/ihuicatl/jupyterlab-urdf/compare/v0.1.1...36b5a10537e1d507d69decc6e39b80b4a20b88e1))

### Bugs fixed

- Fix movement for undefined limits [#17](https://github.com/ihuicatl/jupyterlab-urdf/pull/17) ([@vkmb](https://github.com/vkmb))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ihuicatl/jupyterlab-urdf/graphs/contributors?from=2022-07-20&to=2022-07-29&type=c))

[@github-actions](https://github.com/search?q=repo%3Aihuicatl%2Fjupyterlab-urdf+involves%3Agithub-actions+updated%3A2022-07-20..2022-07-29&type=Issues) | [@ihuicatl](https://github.com/search?q=repo%3Aihuicatl%2Fjupyterlab-urdf+involves%3Aihuicatl+updated%3A2022-07-20..2022-07-29&type=Issues) | [@vkmb](https://github.com/search?q=repo%3Aihuicatl%2Fjupyterlab-urdf+involves%3Avkmb+updated%3A2022-07-20..2022-07-29&type=Issues)

## 0.1.1

([Full Changelog](https://github.com/ihuicatl/jupyterlab-urdf/compare/v0.1.0a0...780dbc0d67539230876d15c3bf1fd9d4dc7e264a))

### Enhancements made

- Configure JupyterLite [#6](https://github.com/ihuicatl/jupyterlab-urdf/pull/6) ([@ihuicatl](https://github.com/ihuicatl))

### Bugs fixed

- Reload robot once error in XML file is cleared [#14](https://github.com/ihuicatl/jupyterlab-urdf/pull/14) ([@ihuicatl](https://github.com/ihuicatl))

### Documentation improvements

- Update README to include JupyterLite [#13](https://github.com/ihuicatl/jupyterlab-urdf/pull/13) ([@ihuicatl](https://github.com/ihuicatl))
- Configure JupyterLite [#6](https://github.com/ihuicatl/jupyterlab-urdf/pull/6) ([@ihuicatl](https://github.com/ihuicatl))
- Update installation instructions [#5](https://github.com/ihuicatl/jupyterlab-urdf/pull/5) ([@ihuicatl](https://github.com/ihuicatl))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ihuicatl/jupyterlab-urdf/graphs/contributors?from=2022-07-06&to=2022-07-20&type=c))

[@github-actions](https://github.com/search?q=repo%3Aihuicatl%2Fjupyterlab-urdf+involves%3Agithub-actions+updated%3A2022-07-06..2022-07-20&type=Issues) | [@ihuicatl](https://github.com/search?q=repo%3Aihuicatl%2Fjupyterlab-urdf+involves%3Aihuicatl+updated%3A2022-07-06..2022-07-20&type=Issues)

## 0.1.0a0

([Full Changelog](https://github.com/ihuicatl/jupyterlab-urdf/compare/3f5977ccd1cbfe59df27b9dc34f5e654da0d1ca9...5ce469cf2ae263c3be22c653150db22d2a5c19b5))

### Enhancements made

- Amphion [#2](https://github.com/ihuicatl/jupyterlab-urdf/pull/2) ([@hbcarlos](https://github.com/hbcarlos))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ihuicatl/jupyterlab-urdf/graphs/contributors?from=2022-06-10&to=2022-07-06&type=c))

[@hbcarlos](https://github.com/search?q=repo%3Aihuicatl%2Fjupyterlab-urdf+involves%3Ahbcarlos+updated%3A2022-06-10..2022-07-06&type=Issues)
